==> pakfire-0.9.28.tar.gz: pakfire-0.9.28/src/pakfire/constants.py <==
#!/usr/bin/python3
###############################################################################
#                                                                             #
# Pakfire - The IPFire package management system                              #
# Copyright (C) 2011 Pakfire development team                                 #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################

import os.path

from .errors import *

from .__version__ import PAKFIRE_VERSION

# The default hub to connect to.
PAKFIRE_HUB = "https://pakfirehub.ipfire.org/"

SYSCONFDIR = "/etc"

CONFIG_DIR = os.path.join(SYSCONFDIR, "pakfire")
CONFIG_DISTRO_DIR = os.path.join(CONFIG_DIR, "distros")

PACKAGE_EXTENSION = "pfm"
MAKEFILE_EXTENSION = "nm"

==> pakfire-0.9.29.tar.gz: pakfire-0.9.29/src/pakfire/constants.py <==
#!/usr/bin/python3
###############################################################################
#                                                                             #
# Pakfire - The IPFire package management system                              #
# Copyright (C) 2011 Pakfire development team                                 #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################

import os.path

from .errors import *

from .__version__ import PAKFIRE_VERSION

# The default hub to connect to.
PAKFIRE_HUB = "https://pakfire.ipfire.org/"

SYSCONFDIR = "/etc"

CONFIG_DIR = os.path.join(SYSCONFDIR, "pakfire")
CONFIG_DISTRO_DIR = os.path.join(CONFIG_DIR, "distros")

PACKAGE_EXTENSION = "pfm"
MAKEFILE_EXTENSION = "nm"
